﻿namespace anbs_cp.Classes;

/// <summary>
/// Обработчик параметров консоли
/// </summary>
/// <param name="consoleParams">Параметры консоли</param>
public sealed class ConsoleParamsParser (IEnumerable<string> consoleParams)
{
    /// <summary>
    /// Массив параметров
    /// </summary>
    private readonly KeyValueList<string, string?> _paramsList = ParseConsoleParams(consoleParams);

    /// <summary>
    /// Парсер параметров
    /// </summary>
    /// <param name="paramsList">Входящий список параметров</param>
    /// <returns></returns>
    private static KeyValueList<string, string?> ParseConsoleParams (IEnumerable<string> paramsList)
    {
        //Создаю список параметров
        KeyValueList<string, string?> result = new();

        //Заполняю его
        foreach (string consoleParam in paramsList)
        {
            //Индекс знака "="
            int eqPlace = consoleParam.IndexOf('=');

            //Получаю параметр
            string param = eqPlace > -1 ? consoleParam[..eqPlace] : consoleParam;

            //Получаю значение параметра
            string? value = eqPlace == -1 ? null : consoleParam[(eqPlace + 1)..].Trim(new[] { '"' });

            //Сохраняю в списке
            result.Add(param.ToLower(), value);
        }

        // Возвращаю значение
        return result;
    }

    /// <summary>
    /// Проверяет наличие параметра
    /// </summary>
    /// <param name="param">Параметр</param>
    /// <returns>Есть ли параметр в списке</returns>
    public bool HasParam (string param) =>
        _paramsList.Any(keyValue => keyValue.Key == param.ToLower());

    /// <summary>
    /// Получает значение параметра
    /// </summary>
    /// <param name="param"></param>
    /// <returns></returns>
    public string? GetValue (string param) =>
        !HasParam(param) ? null : _paramsList.FirstOrDefault(keyValue => keyValue.Key == param.ToLower()).Value;

    /// <summary>
    /// Получает список всех параметров
    /// </summary>
    /// <returns>Список всех параметров</returns>
    public List<string?> GetParamsList () =>
        _paramsList.Select(static keyValue => keyValue.Key?.ToLower()).ToList();
}