﻿namespace anbs_cp.Classes.Exceptions;

/// <summary>
/// Класс-исключение для переименования папок/файлов
/// </summary>
public sealed class RenameException : Exception
{
    /// <summary>
    /// Имя файла/папки
    /// </summary>
    public string FileName { get; }

    /// <summary>
    /// Описание ошибки
    /// </summary>
    public string? ErrorMessage { get; }

    /// <summary>
    /// Конструктор
    /// </summary>
    /// <param name="fileName">Имя файла/папки</param>
    /// <param name="errorMessage">Описание ошибки</param>
    public RenameException(string fileName, string? errorMessage) : base(GetMessage(fileName, errorMessage ?? string.Empty))
    {
        FileName = fileName;
        ErrorMessage = errorMessage;
    }

    /// <summary>
    /// Получение текстового представление ошибки
    /// </summary>
    /// <param name="fileName">Имя файла/папки</param>
    /// <param name="errorMessage">Описание ошибки</param>
    /// <returns>Текстовое представление ошибки</returns>
    private static string GetMessage(string fileName, string errorMessage) =>
        $"При переименовании файла/папки {fileName} возникла следующая ошибка: {errorMessage}";
}