﻿using System.Text;

using anbs_cp.Interfaces;

using Microsoft.AspNetCore.Cryptography.KeyDerivation;

namespace anbs_cp.ForNet.Classes;

/// <summary>
/// Класс шифрования пароля
/// </summary>
public sealed class PasswordEncrypt: IEncryptor
{
    /// <summary>
    /// Шифрование пароля
    /// </summary>
    /// <param name="password">Пароль</param>
    /// <param name="salt">Хэш-код пароля</param>
    /// <param name="valueIfFail">Значение, если неудача</param>
    /// <returns>Зашифрованный пароль</returns>
    public string Encrypt (string password, string salt, string valueIfFail)
    {
        try
        {
            // Получаю byte-массив из хэш-кода пароля
            byte[] saltBytes = Encoding.UTF8.GetBytes(salt);

            // Шифрую пароль
            byte[] encryptedPassword = KeyDerivation.Pbkdf2(password, saltBytes, KeyDerivationPrf.HMACSHA512, 5000, 64);

            // Возвращаю зашифрованный пароль
            return Convert.ToBase64String(encryptedPassword);
        }
        catch (FormatException)
        {
            return valueIfFail;
        }
    }

    /// <summary>
    /// Этот метод не требует реализации в этом классе!
    /// </summary>
    /// <param name="encryptedValue">НЕ РАБОТАЕТ</param>
    /// <param name="salt">НЕ РАБОТАЕТ</param>
    /// <returns>НЕ РАБОТАЕТ</returns>
    /// <param name="valueIfFail">Значение, если неудача</param>
    /// <exception cref="NotImplementedException">Этот метод не требует реализации в этом классе!</exception>
    public string Decrypt (string encryptedValue, string salt, string valueIfFail) =>
        throw new NotImplementedException("Этот метод не требует реализации в этом классе!");

    /// <summary>
    /// Этот метод не требует реализации в этом классе!
    /// </summary>
    /// <param name="text">НЕ РАБОТАЕТ</param>
    /// <param name="valueIfFail">Значение, если неудача</param>
    /// <returns>НЕ РАБОТАЕТ</returns>
    /// <exception cref="NotImplementedException">Этот метод не требует реализации в этом классе!</exception>
    public string Base64UrlEncode (string text, string valueIfFail) =>
        throw new NotImplementedException("Этот метод не требует реализации в этом классе!");

    /// <summary>
    /// Этот метод не требует реализации в этом классе!
    /// </summary>
    /// <param name="text">НЕ РАБОТАЕТ</param>
    /// <returns>НЕ РАБОТАЕТ</returns>
    /// <param name="valueIfFail">Значение, если неудача</param>
    /// <exception cref="NotImplementedException">Этот метод не требует реализации в этом классе!</exception>
    public string Base64UrlDecode (string text, string valueIfFail) =>
        throw new NotImplementedException("Этот метод не требует реализации в этом классе!");
}